@@ -4,7 +4,7 @@ use warnings;
 
 package Path::Tiny;
 # ABSTRACT: File path utility
-our $VERSION = '0.048'; # VERSION
+our $VERSION = '0.050'; # VERSION
 
 # Dependencies
 use Config;
@@ -32,13 +32,7 @@ use overload (
     fallback => 1,
 );
 
-# if cloning, threads should already be loaded, but Win32 pseudoforks
-# don't do that so we have to be sure it's loaded anyway
-my $TID = 0; # for thread safe atomic writes
-
-sub CLONE { require threads; $TID = threads->tid }
-
-my $HAS_UU;  # has Unicode::UTF8; lazily populated
+my $HAS_UU; # has Unicode::UTF8; lazily populated
 
 sub _check_UU {
     eval { require Unicode::UTF8; Unicode::UTF8->VERSION(0.58); 1 };
@@ -443,6 +437,15 @@ sub iterator {
         my $next;
         while (@dirs) {
             if ( ref $dirs[0] eq 'Path::Tiny' ) {
+                if ( !-r $dirs[0] ) {
+                    # Directory is missing or not readable, so skip it.  There
+                    # is still a race condition possible between the check and
+                    # the opendir, but we can't easily differentiate between
+                    # error cases that are OK to skip and those that we want
+                    # to be exceptions, so we live with the race and let opendir
+                    # be fatal.
+                    shift @dirs and next;
+                }
                 $current = $dirs[0];
                 my $dh;
                 opendir( $dh, $current->[PATH] )
@@ -702,7 +705,7 @@ sub spew {
     my $binmode = $args->{binmode};
     # get default binmode from caller's lexical scope (see "perldoc open")
     $binmode = ( ( caller(0) )[10] || {} )->{'open>'} unless defined $binmode;
-    my $temp = path( $self->[PATH] . $TID . $$ );
+    my $temp = path( $self->[PATH] . $$ . int( rand( 2**31 ) ) );
     my $fh = $temp->filehandle( { locked => 1 }, ">", $binmode );
     print {$fh} map { ref eq 'ARRAY' ? @$_ : $_ } @data;
     close $fh or $self->_throw( 'close', $temp->[PATH] );
@@ -839,7 +842,7 @@ Path::Tiny - File path utility
 
 =head1 VERSION
 
-version 0.048
+version 0.050
 
 =head1 SYNOPSIS
 
@@ -1155,7 +1158,8 @@ be included.
 If the C<recurse> option is true, the iterator will walk the directory
 recursively, breadth-first.  If the C<follow_symlinks> option is also true,
 directory links will be followed recursively.  There is no protection against
-loops when following links.
+loops when following links. If a directory is not readable, it will not be
+followed.
 
 The default is the same as:
 
@@ -1546,6 +1550,8 @@ L<File::Next>
 There are probably comparable, non-Tiny tools.  Let me know if you want me to
 add a module to the list.
 
+This module was featured in the L<2013 Perl Advent Calendar|http://www.perladvent.org/2013/2013-12-18.html>.
+
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
@@ -1607,10 +1613,6 @@ Karen Etheridge <ether@cpan.org>
 
 =item *
 
-Keedi Kim <keedi@cpan.org>
-
-=item *
-
 Martin Kjeldsen <mk@bluepipe.dk>
 
 =item *
